@@ -8,6 +8,7 @@
 
 #include <QQmlListProperty>
 #include <QQmlPropertyMap>
+#include <qqmlregistration.h>
 
 #include <KSharedConfig>
 
@@ -19,12 +20,14 @@ class PageDataObject : public QQmlPropertyMap
     Q_PROPERTY(QQmlListProperty<PageDataObject> children READ childrenProperty NOTIFY childrenChanged)
     Q_PROPERTY(bool dirty READ dirty NOTIFY dirtyChanged)
     Q_PROPERTY(QString fileName READ fileName CONSTANT)
+    QML_ELEMENT
+    QML_UNCREATABLE("Used for data storage")
 
 public:
     explicit PageDataObject(const KSharedConfig::Ptr &config, QObject *parent = nullptr);
 
     QQmlListProperty<PageDataObject> childrenProperty() const;
-    QVector<PageDataObject *> children() const;
+    QList<PageDataObject *> children() const;
 
     KSharedConfig::Ptr config() const;
 
@@ -68,7 +71,7 @@ private:
     void updateNames();
 
     QQmlListProperty<PageDataObject> m_childrenProperty;
-    QVector<PageDataObject *> m_children;
+    QList<PageDataObject *> m_children;
     KSharedConfig::Ptr m_config;
     bool m_dirty = false;
     FaceLoader *m_faceLoader = nullptr;
